@@ -1,10 +1,8 @@
 package Data::Localize::Trait::WithStorage;
-use Any::Moose '::Role';
-use Data::Localize::Util qw(_alias_and_deprecate);
+use Moo::Role;
 
 has storage_class => (
-    is => 'ro',
-    isa => 'Str',
+    is => 'lazy',
     default => sub {
         return '+Data::Localize::Storage::Hash';
     }
@@ -12,19 +10,16 @@ has storage_class => (
 
 has storage_args => (
     is => 'ro',
-    isa => 'HashRef',
     default => sub { +{} }
 );
 
 has 'load_from_storage' => (
     is      => 'ro',
-    isa     => 'ArrayRef',
     default => sub { [] },
 );
 
 has lexicon_map => (
     is => 'ro',
-    isa => 'HashRef[Data::Localize::Storage]',
     default => sub { +{} },
 );
 
@@ -35,7 +30,7 @@ after 'BUILD' => sub {
         my $storage_class = $self->_canonicalize_storage_class;
         my $storage_args  = $self->storage_args;
 
-        Any::Moose::load_class( $storage_class );
+        Module::Load::load( $storage_class );
 
         unless ( $storage_class->is_volatile ) {
             foreach my $lang ( @$langs ) {
@@ -51,8 +46,6 @@ after 'BUILD' => sub {
     }
 };
 
-no Any::Moose;
-
 sub get_lexicon_map {
     my ($self, $key) = @_;
     return $self->lexicon_map->{ $key };
@@ -99,7 +92,7 @@ sub _build_storage {
     my $class = $self->_canonicalize_storage_class;
     my $args  = $self->storage_args;
 
-    Any::Moose::load_class($class);
+    Module::Load::load($class);
 
     $args->{lang} = $lang;
 
@@ -115,12 +108,6 @@ sub _canonicalize_storage_class {
     $class;
 }
 
-_alias_and_deprecate lexicon_get => 'get_lexicon';
-_alias_and_deprecate lexicon_set => 'set_lexicon';
-_alias_and_deprecate lexicon_map_get => 'get_lexicon_map';
-_alias_and_deprecate lexicon_map_set => 'set_lexicon_map';
-_alias_and_deprecate lexicon_merge => 'merge_lexicon';
-
 1;
 
 __END__
